/*
 *   This file is part of Dianara
 *   Copyright 2012  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#include "contactlist.h"

ContactList::ContactList(DiasporaController *diasporaController,
                         QWidget *parent) : QWidget(parent)
{
    this->dController = diasporaController;

    mainLayout = new QVBoxLayout();
    mainLayout->setAlignment(Qt::AlignTop);

    //"This is the contact list\n"
    //"If your account is in a Pistos-based pod, you should see your contacts."


    QMap<QString,QString> demoContactData;
    demoContactData.insert("name", "Demo Contact");
    demoContactData.insert("diasporaID", "democontact@somepod.org");
    demoContactData.insert("avatar", "https://joindiaspora.com/images/user/default.png");
    demoContactData.insert("sharing", "true");
    demoContactData.insert("receiving", "false");
    mainLayout->addWidget(new ContactCard(this->dController, demoContactData, this));


    this->setLayout(mainLayout);

    qDebug() << "Contact list created";
}


ContactList::~ContactList()
{
    qDebug() << "Contact list destroyed";
}





/*********************************** SLOTS ***********************************/




void ContactList::setContactListContents(QVariantList contactList)
{
    qDebug() << "Setting contact list contents";


    QMap<QString,QString> contactData;

    foreach (QVariant contact, contactList)
    {
        contactData.insert("name", contact.toMap().value("contact").toMap().value("person").toMap().value("name").toString());
        contactData.insert("diasporaID", contact.toMap().value("contact").toMap().value("person").toMap().value("handle").toString());
        contactData.insert("avatar", contact.toMap().value("contact").toMap().value("person").toMap().value("avatar").toString());
        contactData.insert("sharing", contact.toMap().value("contact").toMap().value("sharing").toString());
        contactData.insert("receiving", contact.toMap().value("contact").toMap().value("receiving").toString());

        this->mainLayout->addWidget(new ContactCard(this->dController,
                                                    contactData,
                                                    this));
    }
}
